pub struct UiOptions {Show 20 fields
pub css_class: Option<String>,
pub input_class: Option<String>,
pub label_class: Option<String>,
pub width: Option<String>,
pub rows: Option<u32>,
pub cols: Option<u32>,
pub autocomplete: Option<String>,
pub autofocus: bool,
pub disabled: bool,
pub readonly: bool,
pub inputmode: Option<String>,
pub heading_level: Option<u8>,
pub max_rating: Option<u32>,
pub scale_min: Option<i32>,
pub scale_max: Option<i32>,
pub scale_step: Option<i32>,
pub scale_labels: Option<ScaleLabels>,
pub show_char_count: bool,
pub custom_attributes: HashMap<String, String>,
pub condition: Option<ConditionRule>,
}Expand description
UI/display options for a form field.
These options control how the field is rendered in HTML.
Fields
css_class: Option<String>CSS class(es) for the field container.
input_class: Option<String>CSS class(es) for the input element.
label_class: Option<String>CSS class(es) for the label.
width: Option<String>Width hint (e.g., “full”, “half”, “third”, “25%”).
rows: Option<u32>Number of rows for textarea.
cols: Option<u32>Number of columns for textarea.
autocomplete: Option<String>Autocomplete attribute value.
autofocus: boolWhether to autofocus this field.
disabled: boolWhether the field is disabled.
readonly: boolWhether the field is read-only.
inputmode: Option<String>Input mode (for mobile keyboards).
heading_level: Option<u8>Heading level for heading fields (1-6).
max_rating: Option<u32>Maximum star rating value.
scale_min: Option<i32>Scale minimum value.
scale_max: Option<i32>Scale maximum value.
scale_step: Option<i32>Scale step value.
scale_labels: Option<ScaleLabels>Labels for scale endpoints.
show_char_count: boolWhether to show the character count.
custom_attributes: HashMap<String, String>Custom HTML attributes as key-value pairs.
condition: Option<ConditionRule>Condition rule for dynamic field visibility.
When present, the field is only shown if the condition evaluates to true.
Implementations